@@ -5,14 +5,14 @@
 #define INCLUDED_OCIO_OPENCOLORABI_H
 
 // Makefile configuration options
-#define OCIO_NAMESPACE OpenColorIO_v2_0
+#define OCIO_NAMESPACE OpenColorIO_v2_1
 
-#define OCIO_VERSION_STR        "2.0.1"
+#define OCIO_VERSION_STR        "2.1.0"
 #define OCIO_VERSION_STATUS_STR ""
-#define OCIO_VERSION_FULL_STR   "2.0.1"
+#define OCIO_VERSION_FULL_STR   "2.1.0"
 
 // Deprecated synonym for downstream projects that expect the 1.x name
-#define OCIO_VERSION            "2.0.1"
+#define OCIO_VERSION            "2.1.0"
 
 /* Version as a single 4-byte hex number, e.g. 0x01050200 == 1.5.2
    Use this for numeric comparisons, e.g. #if OCIO_VERSION_HEX >= ... 
@@ -20,17 +20,31 @@
    this will reflect the original API version number.
    */
 #define OCIO_VERSION_HEX ((2 << 24) | \
-                          (0 << 16) | \
-                          (1 <<  8))
+                          (1 << 16) | \
+                          (0 <<  8))
 
 #define OCIO_VERSION_MAJOR 2
-#define OCIO_VERSION_MINOR 0
+#define OCIO_VERSION_MINOR 1
+
+
+// Highlight deprecated methods or classes.
+#if defined(_MSC_VER)
+    #define OCIO_DEPRECATED(msg) __declspec(deprecated(msg))
+#elif __cplusplus >= 201402L
+    #define OCIO_DEPRECATED(msg) [[deprecated(msg)]]
+#elif defined(__GNUC__) || defined(__clang__)
+    #define OCIO_DEPRECATED(msg) __attribute__((deprecated(msg)))
+#else
+    #define OCIO_DEPRECATED(msg) /* unsupported on this platform */
+#endif
+
 
 // shared_ptr / dynamic_pointer_cast
 #include <memory>
 #define OCIO_SHARED_PTR std::shared_ptr
 #define OCIO_DYNAMIC_POINTER_CAST std::dynamic_pointer_cast
 
+
 // If supported, define OCIOEXPORT, OCIOHIDDEN
 // (used to choose which symbols to export from OpenColorIO)
 #if defined(_WIN32)
